@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2017 Intel Corporation.
+ * Copyright (C) 2014 - 2018 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -64,6 +64,24 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_OPS = {
     .finalize = memkind_arena_finalize
 };
 
+MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_ALL_OPS = {
+    .create = memkind_arena_create,
+    .destroy = memkind_default_destroy,
+    .malloc = memkind_arena_malloc,
+    .calloc = memkind_arena_calloc,
+    .posix_memalign = memkind_arena_posix_memalign,
+    .realloc = memkind_arena_realloc,
+    .free = heap_manager_free,
+    .check_available = memkind_hbw_check_available,
+    .mbind = memkind_default_mbind,
+    .get_mmap_flags = memkind_default_get_mmap_flags,
+    .get_mbind_mode = memkind_default_get_mbind_mode,
+    .get_mbind_nodemask = memkind_hbw_all_get_mbind_nodemask,
+    .get_arena = memkind_thread_get_arena,
+    .init_once = memkind_hbw_all_init_once,
+    .finalize = memkind_arena_finalize
+};
+
 MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_HUGETLB_OPS = {
     .create = memkind_arena_create,
     .destroy = memkind_default_destroy,
@@ -82,6 +100,24 @@ MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_HUGETLB_OPS = {
     .finalize = memkind_arena_finalize
 };
 
+MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_ALL_HUGETLB_OPS = {
+    .create = memkind_arena_create,
+    .destroy = memkind_default_destroy,
+    .malloc = memkind_arena_malloc,
+    .calloc = memkind_arena_calloc,
+    .posix_memalign = memkind_arena_posix_memalign,
+    .realloc = memkind_arena_realloc,
+    .free = heap_manager_free,
+    .check_available = memkind_hbw_hugetlb_check_available,
+    .mbind = memkind_default_mbind,
+    .get_mmap_flags = memkind_hugetlb_get_mmap_flags,
+    .get_mbind_mode = memkind_default_get_mbind_mode,
+    .get_mbind_nodemask = memkind_hbw_all_get_mbind_nodemask,
+    .get_arena = memkind_thread_get_arena,
+    .init_once = memkind_hbw_all_hugetlb_init_once,
+    .finalize = memkind_arena_finalize
+};
+
 MEMKIND_EXPORT struct memkind_ops MEMKIND_HBW_PREFERRED_OPS = {
     .create = memkind_arena_create,
     .destroy = memkind_default_destroy,
@@ -171,13 +207,16 @@ static int numanode_bandwidth_compare(const void *a, const void *b);
 // This declaration is necesarry, cause it's missing in headers from libnuma 2.0.8
 extern unsigned int numa_bitmask_weight(const struct bitmask *bmp );
 
-static void assign_arbitrary_bandwidth_values(int* bandwidth, int bandwidth_len, struct bitmask* hbw_nodes);
+static void assign_arbitrary_bandwidth_values(int *bandwidth, int bandwidth_len,
+                                              struct bitmask *hbw_nodes);
 
-static int fill_bandwidth_values_heuristically (int* bandwidth, int bandwidth_len);
+static int fill_bandwidth_values_heuristically (int *bandwidth,
+                                                int bandwidth_len);
 
-static int fill_bandwidth_values_from_enviroment(int* bandwidth, int bandwidth_len, char *hbw_nodes_env);
+static int fill_bandwidth_values_from_enviroment(int *bandwidth,
+                                                 int bandwidth_len, char *hbw_nodes_env);
 
-static int fill_nodes_bandwidth(int* bandwidth, int bandwidth_len);
+static int fill_nodes_bandwidth(int *bandwidth, int bandwidth_len);
 
 MEMKIND_EXPORT int memkind_hbw_check_available(struct memkind *kind)
 {
@@ -194,22 +233,21 @@ MEMKIND_EXPORT int memkind_hbw_hugetlb_check_available(struct memkind *kind)
 }
 
 MEMKIND_EXPORT int memkind_hbw_get_mbind_nodemask(struct memkind *kind,
-                                   unsigned long *nodemask,
-                                   unsigned long maxnode)
+                                                  unsigned long *nodemask,
+                                                  unsigned long maxnode)
 {
     int cpu;
     struct bitmask nodemask_bm = {maxnode, nodemask};
     struct memkind_hbw_closest_numanode_t *g =
             &memkind_hbw_closest_numanode_g;
     pthread_once(&memkind_hbw_closest_numanode_once_g,
-                memkind_hbw_closest_numanode_init);
+                 memkind_hbw_closest_numanode_init);
     if (MEMKIND_LIKELY(!g->init_err && nodemask)) {
         numa_bitmask_clearall(&nodemask_bm);
         cpu = sched_getcpu();
         if (MEMKIND_LIKELY(cpu < g->num_cpu)) {
             numa_bitmask_setbit(&nodemask_bm, g->closest_numanode[cpu]);
-        }
-        else {
+        } else {
             return MEMKIND_ERROR_RUNTIME;
         }
     }
@@ -217,15 +255,15 @@ MEMKIND_EXPORT int memkind_hbw_get_mbind_nodemask(struct memkind *kind,
 }
 
 MEMKIND_EXPORT int memkind_hbw_all_get_mbind_nodemask(struct memkind *kind,
-                                       unsigned long *nodemask,
-                                       unsigned long maxnode)
+                                                      unsigned long *nodemask,
+                                                      unsigned long maxnode)
 {
     int cpu;
     struct bitmask nodemask_bm = {maxnode, nodemask};
     struct memkind_hbw_closest_numanode_t *g =
             &memkind_hbw_closest_numanode_g;
     pthread_once(&memkind_hbw_closest_numanode_once_g,
-                memkind_hbw_closest_numanode_init);
+                 memkind_hbw_closest_numanode_init);
 
     if (MEMKIND_LIKELY(!g->init_err && nodemask)) {
         numa_bitmask_clearall(&nodemask_bm);
@@ -236,7 +274,8 @@ MEMKIND_EXPORT int memkind_hbw_all_get_mbind_nodemask(struct memkind *kind,
     return g->init_err;
 }
 
-static void assign_arbitrary_bandwidth_values(int* bandwidth, int bandwidth_len, struct bitmask* hbw_nodes)
+static void assign_arbitrary_bandwidth_values(int *bandwidth, int bandwidth_len,
+                                              struct bitmask *hbw_nodes)
 {
     int i, nodes_num = numa_num_configured_nodes();
 
@@ -247,11 +286,9 @@ static void assign_arbitrary_bandwidth_values(int* bandwidth, int bandwidth_len,
     for (i=0; i<NUMA_NUM_NODES; i++) {
         if (i >= nodes_num) {
             bandwidth[i] = 0;
-        }
-        else if (numa_bitmask_isbitset(hbw_nodes, i)) {
+        } else if (numa_bitmask_isbitset(hbw_nodes, i)) {
             bandwidth[i] = 2;
-        }
-        else {
+        } else {
             bandwidth[i] = 1;
         }
     }
@@ -265,11 +302,12 @@ typedef struct registers_t {
     uint32_t edx;
 } registers_t;
 
-inline static void cpuid_asm(int leaf, int subleaf, registers_t* registers) {
+inline static void cpuid_asm(int leaf, int subleaf, registers_t *registers)
+{
     asm volatile("cpuid":"=a"(registers->eax),
-                         "=b"(registers->ebx),
-                         "=c"(registers->ecx),
-                         "=d"(registers->edx):"0"(leaf), "2"(subleaf));
+                 "=b"(registers->ebx),
+                 "=c"(registers->ecx),
+                 "=d"(registers->edx):"0"(leaf), "2"(subleaf));
 }
 
 #define CPUID_MODEL_SHIFT       (4)
@@ -287,11 +325,13 @@ typedef struct {
     uint32_t family;
 } cpu_model_data_t;
 
-static cpu_model_data_t get_cpu_model_data() {
+static cpu_model_data_t get_cpu_model_data()
+{
     registers_t registers;
     cpuid_asm(1, 0, &registers);
     uint32_t model = (registers.eax >> CPUID_MODEL_SHIFT) & CPUID_MODEL_MASK;
-    uint32_t model_ext = (registers.eax >> CPUID_EXT_MODEL_SHIFT) & CPUID_EXT_MODEL_MASK;
+    uint32_t model_ext = (registers.eax >> CPUID_EXT_MODEL_SHIFT) &
+                         CPUID_EXT_MODEL_MASK;
 
     cpu_model_data_t data;
     data.model = model | (model_ext << 4);
@@ -299,16 +339,18 @@ static cpu_model_data_t get_cpu_model_data() {
     return data;
 }
 
-static bool is_hbm_supported(cpu_model_data_t cpu) {
+static bool is_hbm_supported(cpu_model_data_t cpu)
+{
     return cpu.family == CPU_FAMILY_INTEL &&
-        (cpu.model == CPU_MODEL_KNL || cpu.model == CPU_MODEL_KNM);
+           (cpu.model == CPU_MODEL_KNL || cpu.model == CPU_MODEL_KNM);
 }
 
-static int get_high_bandwidth_nodes(struct bitmask* hbw_node_mask) {
+static int get_high_bandwidth_nodes(struct bitmask *hbw_node_mask)
+{
     int nodes_num = numa_num_configured_nodes();
     // Check if NUMA configuration is supported.
     if(nodes_num == 2 || nodes_num == 4 || nodes_num == 8) {
-        struct bitmask* node_cpus = numa_allocate_cpumask();
+        struct bitmask *node_cpus = numa_allocate_cpumask();
 
         assert(hbw_node_mask->size >= nodes_num);
         assert(node_cpus->size >= nodes_num);
@@ -331,8 +373,9 @@ static int get_high_bandwidth_nodes(struct bitmask* hbw_node_mask) {
     return MEMKIND_ERROR_UNAVAILABLE;
 }
 
-static int fill_bandwidth(int* bandwidth, int bandwidth_len) {
-    struct bitmask* hbw_node_mask = numa_allocate_nodemask();
+static int fill_bandwidth(int *bandwidth, int bandwidth_len)
+{
+    struct bitmask *hbw_node_mask = numa_allocate_nodemask();
     int ret = get_high_bandwidth_nodes(hbw_node_mask);
     if(ret == 0) {
         assign_arbitrary_bandwidth_values(bandwidth, bandwidth_len, hbw_node_mask);
@@ -343,7 +386,9 @@ static int fill_bandwidth(int* bandwidth, int bandwidth_len) {
 }
 
 ///This function tries to fill bandwidth array based on knowledge about known CPU models
-static int fill_bandwidth_values_heuristically(int* bandwidth, int bandwidth_len) {
+static int fill_bandwidth_values_heuristically(int *bandwidth,
+                                               int bandwidth_len)
+{
     cpu_model_data_t cpu = get_cpu_model_data();
 
     if(!is_hbm_supported(cpu)) {
@@ -353,26 +398,26 @@ static int fill_bandwidth_values_heuristically(int* bandwidth, int bandwidth_len
     switch(cpu.model) {
         case CPU_MODEL_KNL:
         case CPU_MODEL_KNM: {
-                int ret = fill_bandwidth(bandwidth, bandwidth_len);
-                if(ret == 0) {
-                    log_info("Detected High Bandwidth Memory.");
-                }
-                return ret;
+            int ret = fill_bandwidth(bandwidth, bandwidth_len);
+            if(ret == 0) {
+                log_info("Detected High Bandwidth Memory.");
             }
+            return ret;
+        }
         default:
             return MEMKIND_ERROR_UNAVAILABLE;
     }
 }
 
-static int fill_bandwidth_values_from_enviroment(int* bandwidth, int bandwidth_len, char *hbw_nodes_env)
+static int fill_bandwidth_values_from_enviroment(int *bandwidth,
+                                                 int bandwidth_len, char *hbw_nodes_env)
 {
     struct bitmask *hbw_nodes_bm = numa_parse_nodestring(hbw_nodes_env);
 
     if (!hbw_nodes_bm) {
         log_err("Wrong MEMKIND_HBW_NODES environment value.");
         return MEMKIND_ERROR_ENVIRON;
-    }
-    else {
+    } else {
         assign_arbitrary_bandwidth_values(bandwidth, bandwidth_len, hbw_nodes_bm);
         numa_bitmask_free(hbw_nodes_bm);
     }
@@ -380,17 +425,18 @@ static int fill_bandwidth_values_from_enviroment(int* bandwidth, int bandwidth_l
     return 0;
 }
 
-static int fill_nodes_bandwidth(int* bandwidth, int bandwidth_len)
+static int fill_nodes_bandwidth(int *bandwidth, int bandwidth_len)
 {
-        char *hbw_nodes_env;
+    char *hbw_nodes_env;
 
-        hbw_nodes_env = getenv("MEMKIND_HBW_NODES");
-        if (hbw_nodes_env) {
-            log_info("Environment variable MEMKIND_HBW_NODES detected: %s.", hbw_nodes_env);
-            return fill_bandwidth_values_from_enviroment(bandwidth, bandwidth_len, hbw_nodes_env);
-        }
+    hbw_nodes_env = getenv("MEMKIND_HBW_NODES");
+    if (hbw_nodes_env) {
+        log_info("Environment variable MEMKIND_HBW_NODES detected: %s.", hbw_nodes_env);
+        return fill_bandwidth_values_from_enviroment(bandwidth, bandwidth_len,
+                                                     hbw_nodes_env);
+    }
 
-        return fill_bandwidth_values_heuristically(bandwidth, bandwidth_len);
+    return fill_bandwidth_values_heuristically(bandwidth, bandwidth_len);
 }
 
 static void memkind_hbw_closest_numanode_init(void)
@@ -419,15 +465,10 @@ static void memkind_hbw_closest_numanode_init(void)
         goto exit;
 
     g->init_err = create_bandwidth_nodes(NUMA_NUM_NODES, bandwidth,
-                                             &num_unique, &bandwidth_nodes);
+                                         &num_unique, &bandwidth_nodes);
     if (g->init_err)
         goto exit;
 
-    if (num_unique == 1) {
-       g->init_err = MEMKIND_ERROR_UNAVAILABLE;
-       goto exit;
-    }
-
     high_bandwidth = bandwidth_nodes[num_unique-1].bandwidth;
     g->init_err = set_closest_numanode(num_unique, bandwidth_nodes,
                                        high_bandwidth, g->num_cpu,
@@ -508,7 +549,7 @@ static int create_bandwidth_nodes(int num_bandwidth, const int *bandwidth,
             }
         }
         /* allocate output array */
-        *bandwidth_nodes = (struct bandwidth_nodes_t*)jemk_malloc(
+        *bandwidth_nodes = (struct bandwidth_nodes_t *)jemk_malloc(
                                sizeof(struct bandwidth_nodes_t) * (*num_unique) +
                                sizeof(int) * num_bandwidth);
         if (!*bandwidth_nodes) {
@@ -518,7 +559,7 @@ static int create_bandwidth_nodes(int num_bandwidth, const int *bandwidth,
     }
     if (!err) {
         /* populate output */
-        (*bandwidth_nodes)[0].numanodes = (int*)(*bandwidth_nodes + *num_unique);
+        (*bandwidth_nodes)[0].numanodes = (int *)(*bandwidth_nodes + *num_unique);
         last_bandwidth = numanode_bandwidth[0].bandwidth;
         k = 0;
         l = 0;
@@ -580,8 +621,7 @@ static int set_closest_numanode(int num_unique,
     }
     if (match.bandwidth == -1) {
         err = MEMKIND_ERROR_UNAVAILABLE;
-    }
-    else {
+    } else {
         for (i = 0; i < num_cpunode; ++i) {
             min_distance = INT_MAX;
             min_unique = 1;
@@ -594,8 +634,7 @@ static int set_closest_numanode(int num_unique,
                     min_distance = distance;
                     closest_numanode[i] = match.numanodes[j];
                     min_unique = 1;
-                }
-                else if (distance == min_distance) {
+                } else if (distance == min_distance) {
                     min_unique = 0;
                 }
             }
@@ -628,11 +667,21 @@ MEMKIND_EXPORT void memkind_hbw_init_once(void)
     memkind_init(MEMKIND_HBW, true);
 }
 
+MEMKIND_EXPORT void memkind_hbw_all_init_once(void)
+{
+    memkind_init(MEMKIND_HBW_ALL, true);
+}
+
 MEMKIND_EXPORT void memkind_hbw_hugetlb_init_once(void)
 {
     memkind_init(MEMKIND_HBW_HUGETLB, true);
 }
 
+MEMKIND_EXPORT void memkind_hbw_all_hugetlb_init_once(void)
+{
+    memkind_init(MEMKIND_HBW_ALL_HUGETLB, true);
+}
+
 MEMKIND_EXPORT void memkind_hbw_preferred_init_once(void)
 {
     memkind_init(MEMKIND_HBW_PREFERRED, true);
