@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 - 2016 Intel Corporation.
+ * Copyright (C) 2014 - 2018 Intel Corporation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -22,7 +22,12 @@
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <assert.h>
+#include <memkind/internal/memkind_hugetlb.h>
+#include <memkind/internal/memkind_default.h>
+#include <memkind/internal/memkind_arena.h>
+#include <memkind/internal/memkind_private.h>
+#include <memkind/internal/memkind_log.h>
+
 #include <sys/mman.h>
 #ifndef MAP_HUGETLB
 #define MAP_HUGETLB 0x40000
@@ -38,14 +43,9 @@
 #include <dirent.h>
 #include <jemalloc/jemalloc.h>
 
-#include <memkind/internal/memkind_hugetlb.h>
-#include <memkind/internal/memkind_default.h>
-#include <memkind/internal/memkind_arena.h>
-#include <memkind/internal/memkind_private.h>
-
-const struct memkind_ops MEMKIND_HUGETLB_OPS = {
+MEMKIND_EXPORT struct memkind_ops MEMKIND_HUGETLB_OPS = {
     .create = memkind_arena_create,
-    .destroy = memkind_arena_destroy,
+    .destroy = memkind_default_destroy,
     .malloc = memkind_arena_malloc,
     .calloc = memkind_arena_calloc,
     .posix_memalign = memkind_arena_posix_memalign,
@@ -54,39 +54,37 @@ const struct memkind_ops MEMKIND_HUGETLB_OPS = {
     .check_available = memkind_hugetlb_check_available_2mb,
     .get_mmap_flags = memkind_hugetlb_get_mmap_flags,
     .get_arena = memkind_thread_get_arena,
-    .get_size = memkind_default_get_size,
-    .init_once = memkind_hugetlb_init_once
+    .init_once = memkind_hugetlb_init_once,
+    .finalize = memkind_arena_finalize
 };
 
 static int get_nr_overcommit_hugepages_cached(size_t pagesize, size_t *out);
-static int get_nr_hugepages_cached(size_t pagesize, struct bitmask* nodemask, size_t* out);
+static int get_nr_hugepages_cached(size_t pagesize, struct bitmask *nodemask,
+                                   size_t *out);
 
-static int memkind_hugetlb_check_available(struct memkind *kind, size_t huge_size);
+static int memkind_hugetlb_check_available(struct memkind *kind,
+                                           size_t huge_size);
 
-int memkind_hugetlb_get_mmap_flags(struct memkind *kind, int *flags)
+MEMKIND_EXPORT int memkind_hugetlb_get_mmap_flags(struct memkind *kind,
+                                                  int *flags)
 {
     *flags = MAP_PRIVATE | MAP_ANONYMOUS | MAP_HUGETLB | MAP_HUGE_2MB;
     return 0;
 }
 
-void memkind_hugetlb_init_once(void)
+MEMKIND_EXPORT void memkind_hugetlb_init_once(void)
 {
-    int err = memkind_arena_create_map(MEMKIND_HUGETLB);
-    assert(err == 0);
+    memkind_init(MEMKIND_HUGETLB, false);
 }
 
-int memkind_hugetlb_check_available_2mb(struct memkind *kind)
+MEMKIND_EXPORT int memkind_hugetlb_check_available_2mb(struct memkind *kind)
 {
     return memkind_hugetlb_check_available(kind, 2097152);
 }
 
-int memkind_hugetlb_check_available_1gb(struct memkind *kind)
-{
-    return memkind_hugetlb_check_available(kind, 1073741824);
-}
-
 /* huge_size: the huge page size in bytes */
-static int memkind_hugetlb_check_available(struct memkind *kind, size_t huge_size)
+static int memkind_hugetlb_check_available(struct memkind *kind,
+                                           size_t huge_size)
 {
     int err = 0;
     nodemask_t nodemask;
@@ -99,14 +97,14 @@ static int memkind_hugetlb_check_available(struct memkind *kind, size_t huge_siz
 
     if (kind->ops->get_mbind_nodemask) {
         err = kind->ops->get_mbind_nodemask(kind, nodemask.n, NUMA_NUM_NODES);
-    }
-    else {
+    } else {
         numa_bitmask_setall(&nodemask_bm);
     }
 
     size_t nr_persistent_hugepages, nr_overcommit_hugepages;
 
-    err = get_nr_hugepages_cached(huge_size, &nodemask_bm, &nr_persistent_hugepages);
+    err = get_nr_hugepages_cached(huge_size, &nodemask_bm,
+                                  &nr_persistent_hugepages);
     if(err) {
         return err;
     }
@@ -117,6 +115,7 @@ static int memkind_hugetlb_check_available(struct memkind *kind, size_t huge_siz
     }
 
     if (!nr_overcommit_hugepages && !nr_persistent_hugepages) {
+        log_err("Persistent hugepages and overcommit hugepages are not available.");
         return MEMKIND_ERROR_HUGETLB;
     }
 
@@ -125,7 +124,7 @@ static int memkind_hugetlb_check_available(struct memkind *kind, size_t huge_siz
 
 struct hugepage_size_info {
     size_t size;
-    size_t* nr_hugepages_per_node_array;
+    size_t *nr_hugepages_per_node_array;
     size_t  nr_overcommit;
 };
 
@@ -139,21 +138,25 @@ static pthread_once_t memkind_hugepages_config_once_g = PTHREAD_ONCE_INIT;
 
 static struct hugepage_size_info *allocate_hugepage_size_info()
 {
-    struct hugepage_size_info *newInfo = jemk_malloc(sizeof(struct hugepage_size_info));
+    struct hugepage_size_info *newInfo = jemk_malloc(sizeof(
+                                                         struct hugepage_size_info));
     if(newInfo == NULL) {
+        log_err("jemk_malloc() failed.");
         return NULL;
     }
 
-    newInfo->nr_hugepages_per_node_array = jemk_calloc(NUMA_NUM_NODES, sizeof(size_t));
+    newInfo->nr_hugepages_per_node_array = jemk_calloc(NUMA_NUM_NODES,
+                                                       sizeof(size_t));
     if(newInfo->nr_hugepages_per_node_array == NULL) {
         jemk_free(newInfo);
+        log_err("jemk_calloc() failed.");
         return NULL;
     }
 
     return newInfo;
 }
 
-static size_t get_sysfs_entry_value(const char* entry_path)
+static size_t get_sysfs_entry_value(const char *entry_path)
 {
     int errno_before;
     FILE *fid;
@@ -168,19 +171,21 @@ static size_t get_sysfs_entry_value(const char* entry_path)
             ret  = value_read;
         }
         fclose(fid);
-    }
-    else {
+    } else {
         errno = errno_before;
     }
     return ret;
 }
 
 // construct hugepage_size_info object and fill it with data for provided pagesize
-static void init_hugepage_size_info(size_t pagesize, struct hugepage_size_info *newInfo)
+static void init_hugepage_size_info(size_t pagesize,
+                                    struct hugepage_size_info *newInfo)
 {
     char formatted_path[128];
-    const char *nr_path_fmt = "/sys/devices/system/node/node%u/hugepages/hugepages-%zukB/nr_hugepages";
-    const char *nr_overcommit_path_fmt = "/sys/kernel/mm/hugepages/hugepages-%zukB/nr_overcommit_hugepages";
+    const char *nr_path_fmt =
+        "/sys/devices/system/node/node%u/hugepages/hugepages-%zukB/nr_hugepages";
+    const char *nr_overcommit_path_fmt =
+        "/sys/kernel/mm/hugepages/hugepages-%zukB/nr_overcommit_hugepages";
     int snprintf_ret = 0;
     size_t node;
 
@@ -189,22 +194,31 @@ static void init_hugepage_size_info(size_t pagesize, struct hugepage_size_info *
     newInfo->size = pagesize;
 
     //read overcommit hugepages limit for this pagesize
-    snprintf_ret = snprintf(formatted_path, sizeof(formatted_path), nr_overcommit_path_fmt, pagesize_kb);
+    snprintf_ret = snprintf(formatted_path, sizeof(formatted_path),
+                            nr_overcommit_path_fmt, pagesize_kb);
     if (snprintf_ret > 0 && snprintf_ret < sizeof(formatted_path)) {
         newInfo->nr_overcommit = get_sysfs_entry_value(formatted_path);
+        log_info("Overcommit limit for %zu kB hugepages is %zu.", pagesize,
+                 newInfo->nr_overcommit);
     }
 
     //read every node nr_hugepages for this pagesize
     for (node = 0; node < NUMA_NUM_NODES; ++node) {
-        snprintf_ret = snprintf(formatted_path, sizeof(formatted_path), nr_path_fmt, node, pagesize_kb);
+        snprintf_ret = snprintf(formatted_path, sizeof(formatted_path), nr_path_fmt,
+                                node, pagesize_kb);
         if(snprintf_ret > 0 && snprintf_ret < sizeof(formatted_path)) {
-            newInfo->nr_hugepages_per_node_array[node] = get_sysfs_entry_value(formatted_path);
+            newInfo->nr_hugepages_per_node_array[node] = get_sysfs_entry_value(
+                                                             formatted_path);
+            if(node < numa_num_configured_nodes()) {
+                log_info("Number of %zu kB hugepages on node %zu equals %zu.", pagesize, node,
+                         newInfo->nr_hugepages_per_node_array[node]);
+            }
         }
     }
 }
 
 // get hugepage size in bytes out of sysfs dir name
-static int parse_pagesize_from_sysfs_entry(const char* entry, size_t *out)
+static int parse_pagesize_from_sysfs_entry(const char *entry, size_t *out)
 {
     size_t pagesize;
     int ret = sscanf(entry, "hugepages-%zukB", &pagesize);
@@ -224,22 +238,26 @@ static void hugepages_config_init_once()
     size_t pagesize;
     struct hugepage_size_info **hugepages_info_array = NULL;
     struct dirent *dir;
-    DIR* hugepages_sysfs = opendir("/sys/kernel/mm/hugepages");
+    DIR *hugepages_sysfs = opendir("/sys/kernel/mm/hugepages");
     if(hugepages_sysfs == NULL) {
         memkind_hugepages_config.err = MEMKIND_ERROR_HUGETLB;
+        log_err("/sys/kernel/mm/hugepages directory is not available.");
         return;
     }
 
     unsigned hugepages_info_array_len = 2; //initial size of array
-    hugepages_info_array = jemk_malloc(hugepages_info_array_len * sizeof(struct hugepage_size_info *));
+    hugepages_info_array = jemk_malloc(hugepages_info_array_len * sizeof(
+                                           struct hugepage_size_info *));
     if (hugepages_info_array == NULL) {
         memkind_hugepages_config.err = MEMKIND_ERROR_MALLOC;
         closedir(hugepages_sysfs);
+        log_err("jemk_malloc() failed.");
         return;
     }
 
     while ((dir = readdir(hugepages_sysfs)) != NULL) {
-        if(dir->d_type == DT_DIR && parse_pagesize_from_sysfs_entry(dir->d_name, &pagesize) == 0) {
+        if(dir->d_type == DT_DIR &&
+           parse_pagesize_from_sysfs_entry(dir->d_name, &pagesize) == 0) {
             struct hugepage_size_info *new_hugepage_info = allocate_hugepage_size_info();
             if(new_hugepage_info == NULL) {
                 memkind_hugepages_config.err = MEMKIND_ERROR_MALLOC;
@@ -251,10 +269,12 @@ static void hugepages_config_init_once()
             //there is more hugepage sizes than expected, reallocation of array needed
             if(i == hugepages_info_array_len) {
                 hugepages_info_array_len *= 2;
-                struct hugepage_size_info **swap_tmp = jemk_realloc(hugepages_info_array, hugepages_info_array_len * sizeof(struct hugepage_size_info *));
+                struct hugepage_size_info **swap_tmp = jemk_realloc(hugepages_info_array,
+                                                                    hugepages_info_array_len * sizeof(struct hugepage_size_info *));
                 if(swap_tmp == NULL) {
                     jemk_free(new_hugepage_info);
                     memkind_hugepages_config.err = MEMKIND_ERROR_MALLOC;
+                    log_err("jemk_realloc() failed.");
                     break;
                 }
                 hugepages_info_array = swap_tmp;
@@ -270,8 +290,7 @@ static void hugepages_config_init_once()
     if(memkind_hugepages_config.err == 0) {
         memkind_hugepages_config.hugepages_info_array = hugepages_info_array;
         memkind_hugepages_config.hugepages_info_array_len = i;
-    }
-    else {
+    } else {
         for(j=0; j<i; j++) {
             jemk_free(hugepages_info_array[i]);
         }
@@ -294,7 +313,8 @@ static void destroy_hugepages_per_node()
 }
 
 // helper function that find and return hugepage_size_info object for specified pagesize
-static struct hugepage_size_info* get_hugepage_info_for_pagesize(size_t pagesize)
+static struct hugepage_size_info *get_hugepage_info_for_pagesize(
+    size_t pagesize)
 {
     int i;
 
@@ -307,7 +327,8 @@ static struct hugepage_size_info* get_hugepage_info_for_pagesize(size_t pagesize
 }
 
 // returns sum of pre-allocated hugepage for specified pagesize and set of nodes
-static int get_nr_hugepages_cached(size_t pagesize, struct bitmask* nodemask, size_t *out)
+static int get_nr_hugepages_cached(size_t pagesize, struct bitmask *nodemask,
+                                   size_t *out)
 {
     int i;
     size_t nr_hugepages = 0;
@@ -320,8 +341,9 @@ static int get_nr_hugepages_cached(size_t pagesize, struct bitmask* nodemask, si
         return memkind_hugepages_config.err;
     }
 
-    struct hugepage_size_info* info = get_hugepage_info_for_pagesize(pagesize);
+    struct hugepage_size_info *info = get_hugepage_info_for_pagesize(pagesize);
     if(info == NULL) {
+        log_err("Unable to allocate hugepages, because info about pre-allocated hugepages is not available.");
         return MEMKIND_ERROR_HUGETLB;
     }
 
@@ -345,8 +367,9 @@ static int get_nr_overcommit_hugepages_cached(size_t pagesize, size_t *out)
         return memkind_hugepages_config.err;
     }
 
-    struct hugepage_size_info* info = get_hugepage_info_for_pagesize(pagesize);
+    struct hugepage_size_info *info = get_hugepage_info_for_pagesize(pagesize);
     if(info == NULL) {
+        log_err("Unable to allocate hugepages, because info about overcommit hugepages is not available.");
         return MEMKIND_ERROR_HUGETLB;
     }
 
